# -*- coding: utf-8 -*-
#
#  ServicePosition
#
#  Coded/Modified/Adapted by oerlgrey
#  Based on openHDF image source code
#
#  This code is licensed under the Creative Commons 
#  Attribution-NonCommercial-ShareAlike 3.0 Unported 
#  License. To view a copy of this license, visit
#  http://creativecommons.org/licenses/by-nc-sa/3.0/ 
#  or send a letter to Creative Commons, 559 Nathan 
#  Abbott Way, Stanford, California 94305, USA.
#
#  If you think this license infringes any rights,
#  please contact me at ochzoetna@gmail.com

from Components.Converter.Converter import Converter
from Components.Converter.Poll import Poll
from enigma import iPlayableService
from Components.Element import cached
from Components.config import config

class HDFRadioServicePosition(Poll, Converter):
	TYPE_LENGTH = 0
	TYPE_POSITION = 1
	TYPE_REMAINING = 2

	def __init__(self, type):
		Poll.__init__(self)
		Converter.__init__(self, type)

		if type == "Length":
			self.type = self.TYPE_LENGTH
		elif type == "Position":
			self.type = self.TYPE_POSITION
		elif type == "Remaining":
			self.type = self.TYPE_REMAINING

		if self.type == self.TYPE_LENGTH:
			self.poll_interval = 2000
		else:
			self.poll_interval = 500
		self.poll_enabled = True

	def getSeek(self):
		s = self.source.service
		return s and s.seek()

	@cached
	def getPosition(self):
		seek = self.getSeek()
		if seek is None:
			return None
		if config.plugins.HDFRadio.CUEIsPlaying.value:
			from Plugins.Extensions.HDFRadio.HDFRadio import startCuePTS, actCuePTS
			actpos = 0
			if actCuePTS > startCuePTS:
				actpos = actCuePTS - startCuePTS
			return actpos
		else:
			pos = seek.getPlayPosition()
			if pos[0]:
				return 0
			return pos[1]

	@cached
	def getLength(self):
		seek = self.getSeek()
		if seek is None:
			return None
		if config.plugins.HDFRadio.CUEIsPlaying.value:
			from Plugins.Extensions.HDFRadio.HDFRadio import startCuePTS, endCuePTS
			dur = 0
			if endCuePTS > startCuePTS:
				dur = endCuePTS - startCuePTS
			return dur
		else:
			length = seek.getLength()
			if length[0]:
				return 0
			return length[1]

	@cached
	def getText(self):
		seek = self.getSeek()
		if seek is None:
			return ""

		l = self.length
		p = self.position
		r = self.length - self.position  # Remaining

		if l < 0:
			return ""

		l /= 90000
		p /= 90000
		r /= 90000

		if self.type == self.TYPE_LENGTH:
			return "%d:%02d" % (l / 60, l % 60)
		elif self.type == self.TYPE_POSITION:
			return "-" + "%d:%02d" % (p / 60, p % 60)
		elif self.type == self.TYPE_REMAINING:
			return "+" + "%d:%02d" % (r / 60, r % 60)

	# range/value are for the Progress renderer
	range = 10000

	@cached
	def getValue(self):
		pos = self.position
		len = self.length
		if pos is None or len is None or len <= 0:
			return None
		return pos * 10000 // len

	position = property(getPosition)
	length = property(getLength)
	text = property(getText)
	value = property(getValue)

	def changed(self, what):
		if what[0] is self.CHANGED_SPECIFIC:
			Converter.changed(self, what)
		elif what[0] is self.CHANGED_POLL:
			self.downstream_elements.changed(what)
